<?php
// Do not allow direct access to the file.
if( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Include Kirki Framework File.
get_template_part( 'framework/admin/kirki/kirki' );

/**
 * Override Kirki Textdomain
 *
 * @since 1.0
 */
function fury_kirki_textdomain( $l10n ) {
    $l10n['background-color']  = esc_attr__( 'Background Color', 'fury' );
    return $l10n;
}
add_filter( 'kirki/fury/l10n', 'fury_kirki_textdomain' );

// Include Dynamic CSS File
get_template_part( 'framework/classes/class-fury-dynamic-css' );

/**
 * Customize Register
 *
 * @since 1.0
 */
function fury_customize_register( $wp_customize ) {
    
    // Remove WooCommerce Columns Feature From Customizer
    $wp_customize->remove_control( 'woocommerce_catalog_columns' );
    
}
add_action( 'customize_register', 'fury_customize_register' );

#########################################
# THEME CONFIG
#########################################
Kirki::add_config( 'fury_option', array(
    'capability'    => 'edit_theme_options',
    'option_type'   => 'theme_mod'
) );
#################################################
# GENERAL PANEL
#################################################
Kirki::add_panel( 'fury_general_panel', array(
    'title'     => esc_attr__( 'General', 'fury' ),
    'priority'  => 30
) );
########################################################
# GENERAL BODY SECTION
########################################################
Kirki::add_section( 'fury_general_body_section', array(
    'title' => esc_attr__( 'Body', 'fury' ),
    'panel' => 'fury_general_panel'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Body Font', 'fury' ),
    'tooltip'   => esc_attr__( 'Customize website body font.', 'fury' ),
    'settings'  => 'fury_body_font',
    'section'   => 'fury_general_body_section',
    'type'      => 'typography',
    'transport' => 'auto',
    'choices'   => array(
        'variant'   => array( 'standard', '500', '700', '900' )
    ),
    'default'   => array(
        'font-family'   => 'Maven Pro',
        'variant'       => 'regular',
        'font-size'     => '14px'
    ),
    'output'    => array(
        array(
            'element' => 'body'
        )
    )
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Body Background Color', 'fury' ),
    'tooltip'   => esc_attr__( 'Customize body background color.', 'fury' ),
    'settings'  => 'fury_body_bg_color',
    'section'   => 'fury_general_body_section',
    'type'      => 'color',
    'transport' => 'auto',
    'output'    => array(
        array(
            'element'   => 'body, div.offcanvas-wrapper',
            'property'  => 'background-color'
        )
    ),
    'default'   => '#ffffff'
) );
########################################################
# GENERAL PAGES SECTION
########################################################
Kirki::add_section( 'fury_general_pages_section', array(
    'title' => esc_attr__( 'Pages', 'fury' ),
    'panel' => 'fury_general_panel'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Page Title', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable page titles globally.', 'fury' ),
    'settings'  => 'fury_page_title',
    'section'   => 'fury_general_pages_section',
    'type'      => 'switch',
    'default'   => true
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Page Meta', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable page meta globally. (Page author, category, comments count on very top.)', 'fury' ),
    'settings'  => 'fury_page_meta',
    'section'   => 'fury_general_pages_section',
    'type'      => 'switch',
    'default'   => true
) );
##############################################################
# GENERAL COMMENTS SECTION
##############################################################
Kirki::add_section( 'fury_general_comments_section', array(
    'title' => esc_attr__( 'Comments', 'fury' ),
    'panel' => 'fury_general_panel'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Tags Suggestion', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable tags suggestion below comment form.', 'fury' ),
    'settings'  => 'fury_comments_tags_suggestion',
    'section'   => 'fury_general_comments_section',
    'type'      => 'switch',
    'default'   => true
) );
#############################################
# LAYOUT
#############################################
Kirki::add_panel( 'fury_layout_panel', array(
    'title'     => esc_attr__( 'Layout', 'fury' ),
    'priority'  => 40
) );
#########################################################
# LAYOUT GENERAL SECTION
#########################################################
Kirki::add_section( 'fury_layout_general_section', array(
    'title' => esc_attr__( 'General', 'fury' ),
    'panel' => 'fury_layout_panel'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Sidebar', 'fury' ),
    'tooltip'   => esc_attr__( 'Select sidebar type.', 'fury' ),
    'settings'  => 'fury_sidebar_layout',
    'section'   => 'fury_layout_general_section',
    'type'      => 'select',
    'choices'   => array(
        'right-sidebar' => esc_attr__( 'Right Sidebar', 'fury' ),
        'left-sidebar'  => esc_attr__( 'Left Sidebar', 'fury' ),
        'none'          => esc_attr__( 'No Sidebar', 'fury' )
    ),
    'default'   => 'right-sidebar'
) );
################################################
# HEADER
################################################
Kirki::add_panel( 'fury_header_panel', array(
    'title'     => esc_attr__( 'Header', 'fury' ),
    'priority'  => 40
) );
###########################################################
# HEADER TOP BAR SECTION
###########################################################
Kirki::add_section( 'fury_header_top_bar_section', array(
    'title' => esc_attr__( 'Top Bar', 'fury' ),
    'panel' => 'fury_header_panel'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Top Bar', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable header top bar feature.', 'fury' ),
    'settings'  => 'fury_header_top_bar',
    'section'   => 'fury_header_top_bar_section',
    'type'      => 'switch',
    'default'   => true
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Email', 'fury' ),
    'tooltip'   => esc_attr__( 'Enter your contact email address.', 'fury' ),
    'settings'  => 'fury_header_top_bar_email',
    'section'   => 'fury_header_top_bar_section',
    'type'      => 'text',
    'default'   => 'johndoe@example.com'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Phone', 'fury' ),
    'tooltip'   => esc_attr__( 'Enter your contact phone number.', 'fury' ),
    'settings'  => 'fury_header_top_bar_phone',
    'section'   => 'fury_header_top_bar_section',
    'type'      => 'text',
    'default'   => '00 22 159 4421'
) );
############################################################
# HEADER GENERAL SECTION
############################################################
Kirki::add_section( 'fury_header_general_section', array(
    'title' => esc_attr__( 'General', 'fury' ),
    'panel' => 'fury_header_panel'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Sticky Header', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable sticky header feature.', 'fury' ),
    'settings'  => 'fury_header_sticky',
    'section'   => 'fury_header_general_section',
    'type'      => 'switch',
    'default'   => true
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Profile Icon', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable user profile icon on header right area.', 'fury' ),
    'settings'  => 'fury_header_profile',
    'section'   => 'fury_header_general_section',
    'type'      => 'switch',
    'default'   => true
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Search Icon', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable search icon on header right area.', 'fury' ),
    'settings'  => 'fury_header_search',
    'section'   => 'fury_header_general_section',
    'type'      => 'switch',
    'default'   => true
) );
###########################################
# HEADER LOGO SECTION
###########################################
Kirki::add_section( 'title_tagline', array(
    'title' => esc_attr__( 'Logo', 'fury' ),
    'panel' => 'fury_header_panel'
) );
##########################################
# HEADER IMAGE SECTION
##########################################
Kirki::add_section( 'header_image', array(
    'title' => esc_attr__( 'Header Image', 'fury' ),
    'panel' => 'fury_header_panel'
) );
#############################################
# NAVIGATIONS
#############################################
Kirki::add_panel( 'fury_navigations', array(
    'title'     => esc_attr__( 'Navigations', 'fury' ),
    'priority'  => 50
) );
#########################################################
# OFF-CANVAS NAVIGATION
#########################################################
Kirki::add_section( 'fury_nav_offcanvas_section', array(
    'title' => esc_attr__( 'Off-Canvas Navigation', 'fury' ),
    'panel' => 'fury_navigations'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Enable Navigation', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable Offcanvas navigation on header left side.', 'fury' ),
    'settings'  => 'fury_header_offcanvas_menu',
    'section'   => 'fury_nav_offcanvas_section',
    'type'      => 'switch',
    'default'   => true
) );
####################################################
# BREADCRUMB
####################################################
Kirki::add_panel( 'fury_breadcrumb_panel', array(
    'title'     => esc_attr__( 'Breadcrumb', 'fury' ),
    'priority'  => 50
) );
################################################################
# BREADCRUMB GENERAL SECTION
################################################################
Kirki::add_section( 'fury_breadcrumb_general_section', array(
    'title' => esc_attr__( 'General', 'fury' ),
    'panel' => 'fury_breadcrumb_panel'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Enable', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable breadcrumb feature.', 'fury' ),
    'settings'  => 'fury_breadcrumb_enable',
    'section'   => 'fury_breadcrumb_general_section',
    'type'      => 'switch',
    'default'   => true
) );
################################################################
# BREADCRUMB STYLING SECTION
################################################################
Kirki::add_section( 'fury_breadcrumb_styling_section', array(
    'title' => esc_attr__( 'Styling', 'fury' ),
    'panel' => 'fury_breadcrumb_panel'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Background Color', 'fury' ),
    'tooltip'   => esc_attr__( 'Select breadcrumb background color.', 'fury' ),
    'settings'  => 'fury_breadcrumb_bg_color',
    'section'   => 'fury_breadcrumb_styling_section',
    'type'      => 'color',
    'transport' => 'auto',
    'output'    => array(
        array(
            'element'   => '.page-title',
            'property'  => 'background-color'
        )
    ),
    'default'   => '#f5f5f5'
) );
##############################################
# BLOG
##############################################
Kirki::add_panel( 'fury_blog_panel', array(
    'title'     => esc_attr__( 'Blog', 'fury' ),
    'priority'  => 60
) );
##############################################################
# BLOG SINGLE POST
##############################################################
Kirki::add_section( 'fury_blog_single_post_section', array(
    'title' => esc_attr__( 'Single Post', 'fury' ),
    'panel' => 'fury_blog_panel'
) );
Kirki::add_field( 'fury_options', array(
    'label'     => esc_attr__( 'Posts Title', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable single post titles globally.', 'fury' ),
    'settings'  => 'fury_blog_single_post_title',
    'section'   => 'fury_blog_single_post_section',
    'type'      => 'switch',
    'default'   => true
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Posts Navigation', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable single post prev/next navigation feature.', 'fury' ),
    'settings'  => 'fury_blog_single_post_nav',
    'section'   => 'fury_blog_single_post_section',
    'type'      => 'switch',
    'default'   => true
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Related Articles', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable single post related articles feature.', 'fury' ),
    'settings'  => 'fury_blog_single_post_related_articles',
    'section'   => 'fury_blog_single_post_section',
    'type'      => 'switch',
    'default'   => true
) );
Kirki::add_field( 'fury_option', array(
    'label'             => esc_attr__( 'Related Articles Heading', 'fury' ),
    'tooltip'           => esc_attr__( 'Enter custom title for Related Articles heading.', 'fury' ),
    'settings'          => 'fury_blog_single_post_related_articles_h4',
    'section'           => 'fury_blog_single_post_section',
    'type'              => 'text',
    'active_callback'   => array(
        array(
            'setting'   => 'fury_blog_single_post_related_articles',
            'operator'  => '==',
            'value'     => true
        )
    ),
    'default'           => __( 'You May Also Like', 'fury' )
) );
#######################################################
# BLOG POST META
#######################################################
Kirki::add_section( 'fury_blog_meta_section', array(
    'title' => esc_attr__( 'Post Meta', 'fury' ),
    'panel' => 'fury_blog_panel'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Post Author', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable post meta author.', 'fury' ),
    'settings'  => 'fury_blog_meta_author',
    'section'   => 'fury_blog_meta_section',
    'type'      => 'switch',
    'default'   => true
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Post Date', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable post meta date.', 'fury' ),
    'settings'  => 'fury_blog_meta_date',
    'section'   => 'fury_blog_meta_section',
    'type'      => 'switch',
    'default'   => true
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Post Tags', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable post meta tags.', 'fury' ),
    'settings'  => 'fury_blog_meta_tags',
    'section'   => 'fury_blog_meta_section',
    'type'      => 'switch',
    'default'   => true
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Post Comments', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable post meta comments.', 'fury' ),
    'settings'  => 'fury_blog_meta_comments',
    'section'   => 'fury_blog_meta_section',
    'type'      => 'switch',
    'default'   => true
) );
########################################################
# SOCIAL ICONS
########################################################
Kirki::add_section( 'fury_social_icons_section', array(
    'title'             => esc_attr__( 'Social Icons', 'fury' ),
    'priority'          => 70
) );
Kirki::add_field( 'fury_option', array(
    'label'             => esc_attr__( 'Enable', 'fury' ),
    'tooltip'           => esc_attr__( 'Enable or disable social share feature.', 'fury' ),
    'settings'          => 'fury_social_icons',
    'section'           => 'fury_social_icons_section',
    'type'              => 'switch',
    'default'           => true
) );
Kirki::add_field( 'fury_option', array(
    'label'             => esc_attr__( 'Facebook', 'fury' ),
    'tooltip'           => esc_attr__( 'Enter your Facebbok page url.', 'fury' ),
    'settings'          => 'fury_social_icon_facebook',
    'section'           => 'fury_social_icons_section',
    'type'              => 'text',
    'default'           => '',
    'active_callback'   => array(
        array(
            'setting'   => 'fury_social_icons',
            'operator'  => '==',
            'value'     => true
        )
    )
) );
Kirki::add_field( 'fury_option', array(
    'label'             => esc_attr__( 'Twitter', 'fury' ),
    'tooltip'           => esc_attr__( 'Enter your Twitter page url.', 'fury' ),
    'settings'          => 'fury_social_icon_twitter',
    'section'           => 'fury_social_icons_section',
    'type'              => 'text',
    'default'           => '',
    'active_callback'   => array(
        array(
            'setting'   => 'fury_social_icons',
            'operator'  => '==',
            'value'     => true
        )
    )
) );
Kirki::add_field( 'fury_option', array(
    'label'             => esc_attr__( 'Youtube', 'fury' ),
    'tooltip'           => esc_attr__( 'Enter your YouTube page url.', 'fury' ),
    'settings'          => 'fury_social_icon_youtube',
    'section'           => 'fury_social_icons_section',
    'type'              => 'text',
    'default'           => '',
    'active_callback'   => array(
        array(
            'setting'   => 'fury_social_icons',
            'operator'  => '==',
            'value'     => true
        )
    )
) );
Kirki::add_field( 'fury_option', array(
    'label'             => esc_attr__( 'Instagram', 'fury' ),
    'tooltip'           => esc_attr__( 'Enter your Instagram page url.', 'fury' ),
    'settings'          => 'fury_social_icon_instagram',
    'section'           => 'fury_social_icons_section',
    'type'              => 'text',
    'default'           => '',
    'active_callback'   => array(
        array(
            'setting'   => 'fury_social_icons',
            'operator'  => '==',
            'value'     => true
        )
    )
) );
Kirki::add_field( 'fury_option', array(
    'label'             => esc_attr__( 'Pinterest', 'fury' ),
    'tooltip'           => esc_attr__( 'Enter your Pinterest page url.', 'fury' ),
    'settings'          => 'fury_social_icon_pinterest',
    'section'           => 'fury_social_icons_section',
    'type'              => 'text',
    'default'           => '',
    'active_callback'   => array(
        array(
            'setting'   => 'fury_social_icons',
            'operator'  => '==',
            'value'     => true
        )
    )
) );
##########################################################
# SOCIAL SHARE SECTION
##########################################################
Kirki::add_section( 'fury_social_share_section', array(
    'title'     => esc_attr__( 'Social Share', 'fury' ),
    'priority'  => 80
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Enable', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable or disable social share feature.', 'fury' ),
    'settings'  => 'fury_social_share',
    'section'   => 'fury_social_share_section',
    'type'      => 'switch',
    'default'   => true
) );
Kirki::add_field( 'fury_option', array(
	'type'        => 'sortable',
	'settings'    => 'fury_social_share_sortable',
	'label'       => __( 'Make custom order.', 'fury' ),
	'section'     => 'fury_social_share_section',
	'default'     => array(
		'facebook',
		'twitter',
		'linkedin',
        'google_plus'
	),
	'choices'     => array(
		'facebook'    => esc_attr__( 'Facebook', 'fury' ),
		'twitter'     => esc_attr__( 'Twitter', 'fury' ),
		'linkedin'    => esc_attr__( 'LinkedIn', 'fury' ),
		'google_plus' => esc_attr__( 'Google+', 'fury' )
	),
    'active_callback' => array(
        array(
            'setting'   => 'fury_social_share',
            'operator'  => '==',
            'value'     => true
        )
    )
) );
###################################################
# WOOCOMMERCE PANEL
###################################################
Kirki::add_panel( 'woocommerce', array(
    'title'     => esc_attr__( 'WooCommerce', 'fury' ),
    'priority'  => 110
) );
###############################################################
# WOOCOMMERCE GENERAL SECTION
###############################################################
Kirki::add_section( 'fury_woocommerce_general_section', array(
    'title'     => esc_attr__( 'General', 'fury' ),
    'panel'     => 'woocommerce',
    'priority'  => 1
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Related Products', 'fury' ),
    'tooltip'   => esc_attr__( 'Enable WooCommerce related products section on single product page (bottom).', 'fury' ),
    'settings'  => 'fury_woocommerce_related_products',
    'section'   => 'fury_woocommerce_general_section',
    'type'      => 'switch',
    'default'   => true
) );
################################################
# FOOTER
################################################
Kirki::add_panel( 'fury_footer_panel', array(
    'title'     => esc_attr__( 'Footer', 'fury' ),
    'priority'  => 120,
) );
#########################################################
# FOOTER GENERAL SECTION
#########################################################
Kirki::add_section( 'fury_footer_general_section', array(
    'title' => esc_attr__( 'General', 'fury' ),
    'panel' => 'fury_footer_panel'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Footer Copyright', 'fury' ),
    'tooltip'   => esc_attr__( 'Set custom footer copyright text.', 'fury' ),
    'settings'  => 'fury_footer_copyright',
    'section'   => 'fury_footer_general_section',
    'type'      => 'editor',
    'default'   => ''
) );
#############################################################
# FOOTER STYLING SECTION
#############################################################
Kirki::add_section( 'fury_footer_styling_section', array(
    'title' => esc_attr__( 'Styling', 'fury' ),
    'panel' => 'fury_footer_panel'
) );
Kirki::add_field( 'fury_option', array(
    'label'     => esc_attr__( 'Background Color', 'fury' ),
    'tooltip'   => esc_attr__( 'Select custom footer background color.', 'fury' ),
    'settings'  => 'fury_footer_bg_color',
    'section'   => 'fury_footer_styling_section',
    'type'      => 'color',
    'transport' => 'auto',
    'output'    => array(
        array(
            'element'   => '.site-footer',
            'property'  => 'background-color'
        )
    ),
    'default'   => '#374250'
) );
#################################################################
# WORDPRESS DEFAULT SECTIONS
#################################################################
// Move Homepage Settings Section under General
Kirki::add_section( 'static_front_page', array(
    'title'     => esc_attr__( 'Homepage Settings', 'fury' ),
    'panel'     => 'fury_general_panel',
    'priority'  => 1
) );
// Move Additional CSS Section under General
Kirki::add_section( 'custom_css', array(
    'title'     => esc_attr__( 'Additional CSS', 'fury' ),
    'panel'     => 'fury_general_panel',
    'priority'  => 2
) );

/* Omit closing PHP tag to avoid "Headers already sent" issues. */
